<?php
/**
 * AutoSOAP - Expanded SOAP Server
 * 
 * PHP version 5
 * 
 * @package jp.servlet.AutoSOAP
 * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
 * @copyright 2006 Sakamoto Kouichi
 * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
 * 
 * $Id: AutoSOAP.php 118 2006-04-26 13:37:28Z sakamoto $
 */
include_once(dirname(__FILE__) . "/AutoSOAP/Define.class.php");
include_once(dirname(__FILE__) . "/AutoSOAP/Session.class.php");
include_once(dirname(__FILE__) . "/AutoSOAP/Global.class.php");

include_once(dirname(__FILE__) . "/AutoSOAP/Server.class.php");
include_once(dirname(__FILE__) . "/AutoSOAP/Service.class.php");

include_once(dirname(__FILE__) . "/AutoSOAP/Logger.class.php");
include_once(dirname(__FILE__) . "/AutoSOAP/Filter.class.php");

interface AutoSOAP {
    const VERSION="1.0.0";	
}
?>
